@@ -16,27 +16,31 @@
  *   except in compliance with the License. You may obtain a copy of
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
+
+/*
+ * This file is part of LibreOffice published API.
+ */
 #ifndef INCLUDED_CPPUHELPER_INTERFACECONTAINER_H
 #define INCLUDED_CPPUHELPER_INTERFACECONTAINER_H
 
-#include <sal/config.h>
+#include "sal/config.h"
 
 #include <cstddef>
 #include <functional>
 #include <vector>
 #include <utility>
 
-#include <osl/diagnose.h>
-#include <osl/mutex.hxx>
-#include <rtl/alloc.h>
-#include <com/sun/star/uno/Sequence.hxx>
-#include <com/sun/star/uno/XInterface.hpp>
-#include <com/sun/star/lang/EventObject.hpp>
+#include "osl/diagnose.h"
+#include "osl/mutex.hxx"
+#include "rtl/alloc.h"
+#include "com/sun/star/uno/Sequence.hxx"
+#include "com/sun/star/lang/EventObject.hpp"
 
-#include <com/sun/star/lang/DisposedException.hpp>
-#include <cppuhelper/cppuhelperdllapi.h>
+#include "com/sun/star/lang/DisposedException.hpp"
+#include "cppuhelper/cppuhelperdllapi.h"
+
+namespace com { namespace sun { namespace star { namespace uno { class XInterface; } } } }
 
-/** */ //for docpp
 namespace cppu
 {
 
@@ -48,7 +52,7 @@ namespace detail {
     */
     union element_alias
     {
-        css::uno::Sequence< css::uno::Reference< css::uno::XInterface > > *pAsSequence;
+        std::vector< css::uno::Reference< css::uno::XInterface > > *pAsVector;
         css::uno::XInterface * pAsInterface;
         element_alias() : pAsInterface(NULL) {}
     };
@@ -58,7 +62,7 @@ namespace detail {
 
 class OInterfaceContainerHelper;
 /**
-  This is the iterator of a InterfaceContainerHelper. Typically
+  This is the iterator of an InterfaceContainerHelper. Typically
   one constructs an instance on the stack for one firing session.
   It is not allowed to assign or copy an instance of this class.
 
@@ -124,17 +128,17 @@ private:
 
   @see OInterfaceIteratorHelper
  */
-class CPPUHELPER_DLLPUBLIC OInterfaceContainerHelper
+class SAL_WARN_UNUSED CPPUHELPER_DLLPUBLIC OInterfaceContainerHelper
 {
 public:
     // these are here to force memory de/allocation to sal lib.
-    inline static void * SAL_CALL operator new( size_t nSize )
+    static void * SAL_CALL operator new( size_t nSize )
         { return ::rtl_allocateMemory( nSize ); }
-    inline static void SAL_CALL operator delete( void * pMem )
+    static void SAL_CALL operator delete( void * pMem )
         { ::rtl_freeMemory( pMem ); }
-    inline static void * SAL_CALL operator new( size_t, void * pMem )
+    static void * SAL_CALL operator new( size_t, void * pMem )
         { return pMem; }
-    inline static void SAL_CALL operator delete( void *, void * )
+    static void SAL_CALL operator delete( void *, void * )
         {}
 
     /**
@@ -188,7 +192,7 @@ public:
     sal_Int32 SAL_CALL removeInterface( const css::uno::Reference< css::uno::XInterface > & rxIFace );
     /**
       Call disposing on all object in the container that
-      support XEventListener. Than clear the container.
+      support XEventListener. Then clear the container.
      */
     void SAL_CALL disposeAndClear( const css::lang::EventObject & rEvt );
     /**
@@ -312,13 +316,13 @@ class OMultiTypeInterfaceContainerHelperVar
 {
 public:
     // these are here to force memory de/allocation to sal lib.
-    inline static void * SAL_CALL operator new( size_t nSize )
+    static void * SAL_CALL operator new( size_t nSize )
         { return ::rtl_allocateMemory( nSize ); }
-    inline static void SAL_CALL operator delete( void * pMem )
+    static void SAL_CALL operator delete( void * pMem )
         { ::rtl_freeMemory( pMem ); }
-    inline static void * SAL_CALL operator new( size_t, void * pMem )
+    static void * SAL_CALL operator new( size_t, void * pMem )
         { return pMem; }
-    inline static void SAL_CALL operator delete( void *, void * )
+    static void SAL_CALL operator delete( void *, void * )
         {}
 
     /**
@@ -400,7 +404,7 @@ private:
     InterfaceMap *m_pMap;
     ::osl::Mutex &  rMutex;
 
-    inline typename InterfaceMap::iterator find(const key &rKey) const
+    typename InterfaceMap::iterator find(const key &rKey) const
     {
         typename InterfaceMap::iterator iter = m_pMap->begin();
         typename InterfaceMap::iterator end = m_pMap->end();
@@ -410,7 +414,7 @@ private:
             equalImpl equal;
             if( equal( iter->first, rKey ) )
                 break;
-            iter++;
+            ++iter;
         }
         return iter;
     }
@@ -432,7 +436,7 @@ private:
   can't compile addListener( const container::keyType &key ).
  */
 template < class container , class keyType >
-struct OBroadcastHelperVar
+struct SAL_WARN_UNUSED OBroadcastHelperVar
 {
     /** The shared mutex. */
     ::osl::Mutex &                      rMutex;
@@ -457,7 +461,7 @@ struct OBroadcastHelperVar
     /**
       adds a listener threadsafe.
      **/
-    inline void addListener(
+    void addListener(
         const keyType &key,
         const css::uno::Reference < css::uno::XInterface > &r )
     {
@@ -471,7 +475,7 @@ struct OBroadcastHelperVar
     /**
       removes a listener threadsafe
      **/
-    inline void removeListener(
+    void removeListener(
         const keyType &key,
         const css::uno::Reference < css::uno::XInterface > & r )
     {
@@ -486,7 +490,7 @@ struct OBroadcastHelperVar
                 was not created, null was returned. This can be used to optimize
               performance ( construction of an event object can be avoided ).
      ***/
-    inline OInterfaceContainerHelper * SAL_CALL getContainer( const keyType &key ) const
+    OInterfaceContainerHelper * SAL_CALL getContainer( const keyType &key ) const
         { return aLC.getContainer( key ); }
 };
 
@@ -501,7 +505,7 @@ struct OBroadcastHelperVar
 struct hashType_Impl
 {
     size_t operator()(const css::uno::Type & s) const
-    { return (size_t) s.getTypeName().hashCode(); }
+    { return static_cast<size_t>(s.getTypeName().hashCode()); }
 };
 
 
@@ -512,13 +516,13 @@ class CPPUHELPER_DLLPUBLIC OMultiTypeInterfaceContainerHelper
 {
 public:
     // these are here to force memory de/allocation to sal lib.
-    inline static void * SAL_CALL operator new( size_t nSize )
+    static void * SAL_CALL operator new( size_t nSize )
         { return ::rtl_allocateMemory( nSize ); }
-    inline static void SAL_CALL operator delete( void * pMem )
+    static void SAL_CALL operator delete( void * pMem )
         { ::rtl_freeMemory( pMem ); }
-    inline static void * SAL_CALL operator new( size_t, void * pMem )
+    static void * SAL_CALL operator new( size_t, void * pMem )
         { return pMem; }
-    inline static void SAL_CALL operator delete( void *, void * )
+    static void SAL_CALL operator delete( void *, void * )
         {}
 
     /**
@@ -584,7 +588,7 @@ public:
 
     /**
       Call disposing on all object in the container that
-      support XEventListener. Than clear the container.
+      support XEventListener. Then clear the container.
      */
     void SAL_CALL disposeAndClear( const css::lang::EventObject & rEvt );
     /**
